# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import threads_pb2 as threads__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='events.proto',
  package='org.couchers.api.events',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0c\x65vents.proto\x12\x17org.couchers.api.events\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\rthreads.proto\"&\n\x16OnlineEventInformation\x12\x0c\n\x04link\x18\x01 \x01(\t\"D\n\x17OfflineEventInformation\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0b\n\x03lat\x18\x02 \x01(\x01\x12\x0b\n\x03lng\x18\x03 \x01(\x01\"\xac\x07\n\x05\x45vent\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12\x0f\n\x07is_next\x18\x02 \x01(\x08\x12\r\n\x05title\x18\x05 \x01(\t\x12\x0c\n\x04slug\x18\x06 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x07 \x01(\t\x12\x11\n\tphoto_url\x18\x08 \x01(\t\x12M\n\x12online_information\x18\t \x01(\x0b\x32/.org.couchers.api.events.OnlineEventInformationH\x00\x12O\n\x13offline_information\x18\n \x01(\x0b\x32\x30.org.couchers.api.events.OfflineEventInformationH\x00\x12+\n\x07\x63reated\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0blast_edited\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0f\x63reator_user_id\x18\x0f \x01(\x03\x12.\n\nstart_time\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08timezone\x18\x12 \x01(\t\x12\x1a\n\x12start_time_display\x18\x13 \x01(\t\x12\x18\n\x10\x65nd_time_display\x18\x14 \x01(\t\x12\x42\n\x10\x61ttendance_state\x18\x15 \x01(\x0e\x32(.org.couchers.api.events.AttendanceState\x12\x11\n\torganizer\x18\x16 \x01(\x08\x12\x12\n\nsubscriber\x18\x17 \x01(\x08\x12\x13\n\x0bgoing_count\x18\x18 \x01(\r\x12\x13\n\x0bmaybe_count\x18\x19 \x01(\r\x12\x17\n\x0forganizer_count\x18\x1a \x01(\r\x12\x18\n\x10subscriber_count\x18\x1b \x01(\r\x12\x17\n\rowner_user_id\x18\x1c \x01(\x03H\x01\x12\x1c\n\x12owner_community_id\x18\x1d \x01(\x03H\x01\x12\x18\n\x0eowner_group_id\x18\x1e \x01(\x03H\x01\x12\x30\n\x06thread\x18\" \x01(\x0b\x32 .org.couchers.api.threads.Thread\x12\x10\n\x08\x63\x61n_edit\x18  \x01(\x08\x12\x14\n\x0c\x63\x61n_moderate\x18! \x01(\x08\x42\x06\n\x04modeB\x07\n\x05owner\"\xf8\x02\n\x0e\x43reateEventReq\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x11\n\tphoto_key\x18\x03 \x01(\t\x12M\n\x12online_information\x18\x04 \x01(\x0b\x32/.org.couchers.api.events.OnlineEventInformationH\x00\x12O\n\x13offline_information\x18\x05 \x01(\x0b\x32\x30.org.couchers.api.events.OfflineEventInformationH\x00\x12\x1b\n\x13parent_community_id\x18\x08 \x01(\x03\x12.\n\nstart_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08timezone\x18\x0b \x01(\tB\x06\n\x04mode\"\xe0\x02\n\x10ScheduleEventReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x11\n\tphoto_key\x18\x03 \x01(\t\x12M\n\x12online_information\x18\x04 \x01(\x0b\x32/.org.couchers.api.events.OnlineEventInformationH\x00\x12O\n\x13offline_information\x18\x05 \x01(\x0b\x32\x30.org.couchers.api.events.OfflineEventInformationH\x00\x12.\n\nstart_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08timezone\x18\n \x01(\tB\x06\n\x04mode\"\x80\x04\n\x0eUpdateEventReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12\x19\n\x11update_all_future\x18\x02 \x01(\x08\x12+\n\x05title\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63ontent\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tphoto_key\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12M\n\x12online_information\x18\x06 \x01(\x0b\x32/.org.couchers.api.events.OnlineEventInformationH\x00\x12O\n\x13offline_information\x18\x07 \x01(\x0b\x32\x30.org.couchers.api.events.OfflineEventInformationH\x00\x12.\n\nstart_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\x08timezone\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x06\n\x04mode\"\x1f\n\x0bGetEventReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\"P\n\x15ListEventAttendeesReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"K\n\x15ListEventAttendeesRes\x12\x19\n\x11\x61ttendee_user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"R\n\x17ListEventSubscribersReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"O\n\x17ListEventSubscribersRes\x12\x1b\n\x13subscriber_user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"Q\n\x16ListEventOrganizersReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"M\n\x16ListEventOrganizersRes\x12\x1a\n\x12organizer_user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x81\x01\n\x0fListMyEventsReq\x12\x0c\n\x04past\x18\x01 \x01(\x08\x12\x12\n\nsubscribed\x18\x02 \x01(\x08\x12\x11\n\tattending\x18\x03 \x01(\x08\x12\x12\n\norganizing\x18\x04 \x01(\x08\x12\x11\n\tpage_size\x18\x05 \x01(\r\x12\x12\n\npage_token\x18\x06 \x01(\t\"Z\n\x0fListMyEventsRes\x12.\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1e.org.couchers.api.events.Event\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"G\n\x10ListAllEventsReq\x12\x0c\n\x04past\x18\x01 \x01(\x08\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"[\n\x10ListAllEventsRes\x12.\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1e.org.couchers.api.events.Event\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"`\n\x17ListEventOccurrencesReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12\x0c\n\x04past\x18\x02 \x01(\x08\x12\x11\n\tpage_size\x18\x03 \x01(\r\x12\x12\n\npage_token\x18\x04 \x01(\t\"b\n\x17ListEventOccurrencesRes\x12.\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1e.org.couchers.api.events.Event\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"q\n\x10TransferEventReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12 \n\x16new_owner_community_id\x18\x03 \x01(\x03H\x00\x12\x1c\n\x12new_owner_group_id\x18\x02 \x01(\x03H\x00\x42\x0b\n\tnew_owner\">\n\x17SetEventSubscriptionReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12\x11\n\tsubscribe\x18\x02 \x01(\x08\"m\n\x15SetEventAttendanceReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12\x42\n\x10\x61ttendance_state\x18\x02 \x01(\x0e\x32(.org.couchers.api.events.AttendanceState\"<\n\x17InviteEventOrganizerReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12\x0f\n\x07user_id\x18\x02 \x01(\x03\"+\n\x17RemoveEventOrganizerReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03*i\n\x0f\x41ttendanceState\x12\x1e\n\x1a\x41TTENDANCE_STATE_NOT_GOING\x10\x00\x12\x1a\n\x16\x41TTENDANCE_STATE_MAYBE\x10\x01\x12\x1a\n\x16\x41TTENDANCE_STATE_GOING\x10\x02\x32\xac\x0c\n\x06\x45vents\x12X\n\x0b\x43reateEvent\x12\'.org.couchers.api.events.CreateEventReq\x1a\x1e.org.couchers.api.events.Event\"\x00\x12\\\n\rScheduleEvent\x12).org.couchers.api.events.ScheduleEventReq\x1a\x1e.org.couchers.api.events.Event\"\x00\x12X\n\x0bUpdateEvent\x12\'.org.couchers.api.events.UpdateEventReq\x1a\x1e.org.couchers.api.events.Event\"\x00\x12R\n\x08GetEvent\x12$.org.couchers.api.events.GetEventReq\x1a\x1e.org.couchers.api.events.Event\"\x00\x12|\n\x14ListEventOccurrences\x12\x30.org.couchers.api.events.ListEventOccurrencesReq\x1a\x30.org.couchers.api.events.ListEventOccurrencesRes\"\x00\x12v\n\x12ListEventAttendees\x12..org.couchers.api.events.ListEventAttendeesReq\x1a..org.couchers.api.events.ListEventAttendeesRes\"\x00\x12|\n\x14ListEventSubscribers\x12\x30.org.couchers.api.events.ListEventSubscribersReq\x1a\x30.org.couchers.api.events.ListEventSubscribersRes\"\x00\x12y\n\x13ListEventOrganizers\x12/.org.couchers.api.events.ListEventOrganizersReq\x1a/.org.couchers.api.events.ListEventOrganizersRes\"\x00\x12\\\n\rTransferEvent\x12).org.couchers.api.events.TransferEventReq\x1a\x1e.org.couchers.api.events.Event\"\x00\x12j\n\x14SetEventSubscription\x12\x30.org.couchers.api.events.SetEventSubscriptionReq\x1a\x1e.org.couchers.api.events.Event\"\x00\x12\x66\n\x12SetEventAttendance\x12..org.couchers.api.events.SetEventAttendanceReq\x1a\x1e.org.couchers.api.events.Event\"\x00\x12\x62\n\x14InviteEventOrganizer\x12\x30.org.couchers.api.events.InviteEventOrganizerReq\x1a\x16.google.protobuf.Empty\"\x00\x12\x62\n\x14RemoveEventOrganizer\x12\x30.org.couchers.api.events.RemoveEventOrganizerReq\x1a\x16.google.protobuf.Empty\"\x00\x12\x64\n\x0cListMyEvents\x12(.org.couchers.api.events.ListMyEventsReq\x1a(.org.couchers.api.events.ListMyEventsRes\"\x00\x12g\n\rListAllEvents\x12).org.couchers.api.events.ListAllEventsReq\x1a).org.couchers.api.events.ListAllEventsRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,threads__pb2.DESCRIPTOR,])

_ATTENDANCESTATE = _descriptor.EnumDescriptor(
  name='AttendanceState',
  full_name='org.couchers.api.events.AttendanceState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ATTENDANCE_STATE_NOT_GOING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ATTENDANCE_STATE_MAYBE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ATTENDANCE_STATE_GOING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3975,
  serialized_end=4080,
)
_sym_db.RegisterEnumDescriptor(_ATTENDANCESTATE)

AttendanceState = enum_type_wrapper.EnumTypeWrapper(_ATTENDANCESTATE)
ATTENDANCE_STATE_NOT_GOING = 0
ATTENDANCE_STATE_MAYBE = 1
ATTENDANCE_STATE_GOING = 2



_ONLINEEVENTINFORMATION = _descriptor.Descriptor(
  name='OnlineEventInformation',
  full_name='org.couchers.api.events.OnlineEventInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='link', full_name='org.couchers.api.events.OnlineEventInformation.link', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=207,
)


_OFFLINEEVENTINFORMATION = _descriptor.Descriptor(
  name='OfflineEventInformation',
  full_name='org.couchers.api.events.OfflineEventInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='org.couchers.api.events.OfflineEventInformation.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lat', full_name='org.couchers.api.events.OfflineEventInformation.lat', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lng', full_name='org.couchers.api.events.OfflineEventInformation.lng', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=277,
)


_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='org.couchers.api.events.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='org.couchers.api.events.Event.event_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_next', full_name='org.couchers.api.events.Event.is_next', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='org.couchers.api.events.Event.title', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slug', full_name='org.couchers.api.events.Event.slug', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='org.couchers.api.events.Event.content', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='photo_url', full_name='org.couchers.api.events.Event.photo_url', index=5,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_information', full_name='org.couchers.api.events.Event.online_information', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offline_information', full_name='org.couchers.api.events.Event.offline_information', index=7,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='org.couchers.api.events.Event.created', index=8,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_edited', full_name='org.couchers.api.events.Event.last_edited', index=9,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creator_user_id', full_name='org.couchers.api.events.Event.creator_user_id', index=10,
      number=15, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='org.couchers.api.events.Event.start_time', index=11,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='org.couchers.api.events.Event.end_time', index=12,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timezone', full_name='org.couchers.api.events.Event.timezone', index=13,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time_display', full_name='org.couchers.api.events.Event.start_time_display', index=14,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time_display', full_name='org.couchers.api.events.Event.end_time_display', index=15,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attendance_state', full_name='org.couchers.api.events.Event.attendance_state', index=16,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='organizer', full_name='org.couchers.api.events.Event.organizer', index=17,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subscriber', full_name='org.couchers.api.events.Event.subscriber', index=18,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='going_count', full_name='org.couchers.api.events.Event.going_count', index=19,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maybe_count', full_name='org.couchers.api.events.Event.maybe_count', index=20,
      number=25, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='organizer_count', full_name='org.couchers.api.events.Event.organizer_count', index=21,
      number=26, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subscriber_count', full_name='org.couchers.api.events.Event.subscriber_count', index=22,
      number=27, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_user_id', full_name='org.couchers.api.events.Event.owner_user_id', index=23,
      number=28, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_community_id', full_name='org.couchers.api.events.Event.owner_community_id', index=24,
      number=29, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_group_id', full_name='org.couchers.api.events.Event.owner_group_id', index=25,
      number=30, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thread', full_name='org.couchers.api.events.Event.thread', index=26,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_edit', full_name='org.couchers.api.events.Event.can_edit', index=27,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_moderate', full_name='org.couchers.api.events.Event.can_moderate', index=28,
      number=33, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='mode', full_name='org.couchers.api.events.Event.mode',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='owner', full_name='org.couchers.api.events.Event.owner',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=280,
  serialized_end=1220,
)


_CREATEEVENTREQ = _descriptor.Descriptor(
  name='CreateEventReq',
  full_name='org.couchers.api.events.CreateEventReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='org.couchers.api.events.CreateEventReq.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='org.couchers.api.events.CreateEventReq.content', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='photo_key', full_name='org.couchers.api.events.CreateEventReq.photo_key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_information', full_name='org.couchers.api.events.CreateEventReq.online_information', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offline_information', full_name='org.couchers.api.events.CreateEventReq.offline_information', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_community_id', full_name='org.couchers.api.events.CreateEventReq.parent_community_id', index=5,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='org.couchers.api.events.CreateEventReq.start_time', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='org.couchers.api.events.CreateEventReq.end_time', index=7,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timezone', full_name='org.couchers.api.events.CreateEventReq.timezone', index=8,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='mode', full_name='org.couchers.api.events.CreateEventReq.mode',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1223,
  serialized_end=1599,
)


_SCHEDULEEVENTREQ = _descriptor.Descriptor(
  name='ScheduleEventReq',
  full_name='org.couchers.api.events.ScheduleEventReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='org.couchers.api.events.ScheduleEventReq.event_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='org.couchers.api.events.ScheduleEventReq.content', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='photo_key', full_name='org.couchers.api.events.ScheduleEventReq.photo_key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_information', full_name='org.couchers.api.events.ScheduleEventReq.online_information', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offline_information', full_name='org.couchers.api.events.ScheduleEventReq.offline_information', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='org.couchers.api.events.ScheduleEventReq.start_time', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='org.couchers.api.events.ScheduleEventReq.end_time', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timezone', full_name='org.couchers.api.events.ScheduleEventReq.timezone', index=7,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='mode', full_name='org.couchers.api.events.ScheduleEventReq.mode',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1602,
  serialized_end=1954,
)


_UPDATEEVENTREQ = _descriptor.Descriptor(
  name='UpdateEventReq',
  full_name='org.couchers.api.events.UpdateEventReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='org.couchers.api.events.UpdateEventReq.event_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_all_future', full_name='org.couchers.api.events.UpdateEventReq.update_all_future', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='org.couchers.api.events.UpdateEventReq.title', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='org.couchers.api.events.UpdateEventReq.content', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='photo_key', full_name='org.couchers.api.events.UpdateEventReq.photo_key', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_information', full_name='org.couchers.api.events.UpdateEventReq.online_information', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offline_information', full_name='org.couchers.api.events.UpdateEventReq.offline_information', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='org.couchers.api.events.UpdateEventReq.start_time', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='org.couchers.api.events.UpdateEventReq.end_time', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timezone', full_name='org.couchers.api.events.UpdateEventReq.timezone', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='mode', full_name='org.couchers.api.events.UpdateEventReq.mode',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1957,
  serialized_end=2469,
)


_GETEVENTREQ = _descriptor.Descriptor(
  name='GetEventReq',
  full_name='org.couchers.api.events.GetEventReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='org.couchers.api.events.GetEventReq.event_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2471,
  serialized_end=2502,
)


_LISTEVENTATTENDEESREQ = _descriptor.Descriptor(
  name='ListEventAttendeesReq',
  full_name='org.couchers.api.events.ListEventAttendeesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='org.couchers.api.events.ListEventAttendeesReq.event_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.events.ListEventAttendeesReq.page_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.events.ListEventAttendeesReq.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2504,
  serialized_end=2584,
)


_LISTEVENTATTENDEESRES = _descriptor.Descriptor(
  name='ListEventAttendeesRes',
  full_name='org.couchers.api.events.ListEventAttendeesRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='attendee_user_ids', full_name='org.couchers.api.events.ListEventAttendeesRes.attendee_user_ids', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.events.ListEventAttendeesRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2586,
  serialized_end=2661,
)


_LISTEVENTSUBSCRIBERSREQ = _descriptor.Descriptor(
  name='ListEventSubscribersReq',
  full_name='org.couchers.api.events.ListEventSubscribersReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='org.couchers.api.events.ListEventSubscribersReq.event_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.events.ListEventSubscribersReq.page_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.events.ListEventSubscribersReq.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2663,
  serialized_end=2745,
)


_LISTEVENTSUBSCRIBERSRES = _descriptor.Descriptor(
  name='ListEventSubscribersRes',
  full_name='org.couchers.api.events.ListEventSubscribersRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subscriber_user_ids', full_name='org.couchers.api.events.ListEventSubscribersRes.subscriber_user_ids', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.events.ListEventSubscribersRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2747,
  serialized_end=2826,
)


_LISTEVENTORGANIZERSREQ = _descriptor.Descriptor(
  name='ListEventOrganizersReq',
  full_name='org.couchers.api.events.ListEventOrganizersReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='org.couchers.api.events.ListEventOrganizersReq.event_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.events.ListEventOrganizersReq.page_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.events.ListEventOrganizersReq.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2828,
  serialized_end=2909,
)


_LISTEVENTORGANIZERSRES = _descriptor.Descriptor(
  name='ListEventOrganizersRes',
  full_name='org.couchers.api.events.ListEventOrganizersRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='organizer_user_ids', full_name='org.couchers.api.events.ListEventOrganizersRes.organizer_user_ids', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.events.ListEventOrganizersRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2911,
  serialized_end=2988,
)


_LISTMYEVENTSREQ = _descriptor.Descriptor(
  name='ListMyEventsReq',
  full_name='org.couchers.api.events.ListMyEventsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='past', full_name='org.couchers.api.events.ListMyEventsReq.past', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subscribed', full_name='org.couchers.api.events.ListMyEventsReq.subscribed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attending', full_name='org.couchers.api.events.ListMyEventsReq.attending', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='organizing', full_name='org.couchers.api.events.ListMyEventsReq.organizing', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.events.ListMyEventsReq.page_size', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.events.ListMyEventsReq.page_token', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2991,
  serialized_end=3120,
)


_LISTMYEVENTSRES = _descriptor.Descriptor(
  name='ListMyEventsRes',
  full_name='org.couchers.api.events.ListMyEventsRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='org.couchers.api.events.ListMyEventsRes.events', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.events.ListMyEventsRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3122,
  serialized_end=3212,
)


_LISTALLEVENTSREQ = _descriptor.Descriptor(
  name='ListAllEventsReq',
  full_name='org.couchers.api.events.ListAllEventsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='past', full_name='org.couchers.api.events.ListAllEventsReq.past', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.events.ListAllEventsReq.page_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.events.ListAllEventsReq.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3214,
  serialized_end=3285,
)


_LISTALLEVENTSRES = _descriptor.Descriptor(
  name='ListAllEventsRes',
  full_name='org.couchers.api.events.ListAllEventsRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='org.couchers.api.events.ListAllEventsRes.events', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.events.ListAllEventsRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3287,
  serialized_end=3378,
)


_LISTEVENTOCCURRENCESREQ = _descriptor.Descriptor(
  name='ListEventOccurrencesReq',
  full_name='org.couchers.api.events.ListEventOccurrencesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='org.couchers.api.events.ListEventOccurrencesReq.event_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='past', full_name='org.couchers.api.events.ListEventOccurrencesReq.past', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.events.ListEventOccurrencesReq.page_size', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.events.ListEventOccurrencesReq.page_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3380,
  serialized_end=3476,
)


_LISTEVENTOCCURRENCESRES = _descriptor.Descriptor(
  name='ListEventOccurrencesRes',
  full_name='org.couchers.api.events.ListEventOccurrencesRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='org.couchers.api.events.ListEventOccurrencesRes.events', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.events.ListEventOccurrencesRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3478,
  serialized_end=3576,
)


_TRANSFEREVENTREQ = _descriptor.Descriptor(
  name='TransferEventReq',
  full_name='org.couchers.api.events.TransferEventReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='org.couchers.api.events.TransferEventReq.event_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_owner_community_id', full_name='org.couchers.api.events.TransferEventReq.new_owner_community_id', index=1,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_owner_group_id', full_name='org.couchers.api.events.TransferEventReq.new_owner_group_id', index=2,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='new_owner', full_name='org.couchers.api.events.TransferEventReq.new_owner',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3578,
  serialized_end=3691,
)


_SETEVENTSUBSCRIPTIONREQ = _descriptor.Descriptor(
  name='SetEventSubscriptionReq',
  full_name='org.couchers.api.events.SetEventSubscriptionReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='org.couchers.api.events.SetEventSubscriptionReq.event_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subscribe', full_name='org.couchers.api.events.SetEventSubscriptionReq.subscribe', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3693,
  serialized_end=3755,
)


_SETEVENTATTENDANCEREQ = _descriptor.Descriptor(
  name='SetEventAttendanceReq',
  full_name='org.couchers.api.events.SetEventAttendanceReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='org.couchers.api.events.SetEventAttendanceReq.event_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attendance_state', full_name='org.couchers.api.events.SetEventAttendanceReq.attendance_state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3757,
  serialized_end=3866,
)


_INVITEEVENTORGANIZERREQ = _descriptor.Descriptor(
  name='InviteEventOrganizerReq',
  full_name='org.couchers.api.events.InviteEventOrganizerReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='org.couchers.api.events.InviteEventOrganizerReq.event_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='org.couchers.api.events.InviteEventOrganizerReq.user_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3868,
  serialized_end=3928,
)


_REMOVEEVENTORGANIZERREQ = _descriptor.Descriptor(
  name='RemoveEventOrganizerReq',
  full_name='org.couchers.api.events.RemoveEventOrganizerReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='org.couchers.api.events.RemoveEventOrganizerReq.event_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3930,
  serialized_end=3973,
)

_EVENT.fields_by_name['online_information'].message_type = _ONLINEEVENTINFORMATION
_EVENT.fields_by_name['offline_information'].message_type = _OFFLINEEVENTINFORMATION
_EVENT.fields_by_name['created'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENT.fields_by_name['last_edited'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENT.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENT.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENT.fields_by_name['attendance_state'].enum_type = _ATTENDANCESTATE
_EVENT.fields_by_name['thread'].message_type = threads__pb2._THREAD
_EVENT.oneofs_by_name['mode'].fields.append(
  _EVENT.fields_by_name['online_information'])
_EVENT.fields_by_name['online_information'].containing_oneof = _EVENT.oneofs_by_name['mode']
_EVENT.oneofs_by_name['mode'].fields.append(
  _EVENT.fields_by_name['offline_information'])
_EVENT.fields_by_name['offline_information'].containing_oneof = _EVENT.oneofs_by_name['mode']
_EVENT.oneofs_by_name['owner'].fields.append(
  _EVENT.fields_by_name['owner_user_id'])
_EVENT.fields_by_name['owner_user_id'].containing_oneof = _EVENT.oneofs_by_name['owner']
_EVENT.oneofs_by_name['owner'].fields.append(
  _EVENT.fields_by_name['owner_community_id'])
_EVENT.fields_by_name['owner_community_id'].containing_oneof = _EVENT.oneofs_by_name['owner']
_EVENT.oneofs_by_name['owner'].fields.append(
  _EVENT.fields_by_name['owner_group_id'])
_EVENT.fields_by_name['owner_group_id'].containing_oneof = _EVENT.oneofs_by_name['owner']
_CREATEEVENTREQ.fields_by_name['online_information'].message_type = _ONLINEEVENTINFORMATION
_CREATEEVENTREQ.fields_by_name['offline_information'].message_type = _OFFLINEEVENTINFORMATION
_CREATEEVENTREQ.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CREATEEVENTREQ.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CREATEEVENTREQ.oneofs_by_name['mode'].fields.append(
  _CREATEEVENTREQ.fields_by_name['online_information'])
_CREATEEVENTREQ.fields_by_name['online_information'].containing_oneof = _CREATEEVENTREQ.oneofs_by_name['mode']
_CREATEEVENTREQ.oneofs_by_name['mode'].fields.append(
  _CREATEEVENTREQ.fields_by_name['offline_information'])
_CREATEEVENTREQ.fields_by_name['offline_information'].containing_oneof = _CREATEEVENTREQ.oneofs_by_name['mode']
_SCHEDULEEVENTREQ.fields_by_name['online_information'].message_type = _ONLINEEVENTINFORMATION
_SCHEDULEEVENTREQ.fields_by_name['offline_information'].message_type = _OFFLINEEVENTINFORMATION
_SCHEDULEEVENTREQ.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCHEDULEEVENTREQ.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCHEDULEEVENTREQ.oneofs_by_name['mode'].fields.append(
  _SCHEDULEEVENTREQ.fields_by_name['online_information'])
_SCHEDULEEVENTREQ.fields_by_name['online_information'].containing_oneof = _SCHEDULEEVENTREQ.oneofs_by_name['mode']
_SCHEDULEEVENTREQ.oneofs_by_name['mode'].fields.append(
  _SCHEDULEEVENTREQ.fields_by_name['offline_information'])
_SCHEDULEEVENTREQ.fields_by_name['offline_information'].containing_oneof = _SCHEDULEEVENTREQ.oneofs_by_name['mode']
_UPDATEEVENTREQ.fields_by_name['title'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEEVENTREQ.fields_by_name['content'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEEVENTREQ.fields_by_name['photo_key'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEEVENTREQ.fields_by_name['online_information'].message_type = _ONLINEEVENTINFORMATION
_UPDATEEVENTREQ.fields_by_name['offline_information'].message_type = _OFFLINEEVENTINFORMATION
_UPDATEEVENTREQ.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_UPDATEEVENTREQ.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_UPDATEEVENTREQ.fields_by_name['timezone'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEEVENTREQ.oneofs_by_name['mode'].fields.append(
  _UPDATEEVENTREQ.fields_by_name['online_information'])
_UPDATEEVENTREQ.fields_by_name['online_information'].containing_oneof = _UPDATEEVENTREQ.oneofs_by_name['mode']
_UPDATEEVENTREQ.oneofs_by_name['mode'].fields.append(
  _UPDATEEVENTREQ.fields_by_name['offline_information'])
_UPDATEEVENTREQ.fields_by_name['offline_information'].containing_oneof = _UPDATEEVENTREQ.oneofs_by_name['mode']
_LISTMYEVENTSRES.fields_by_name['events'].message_type = _EVENT
_LISTALLEVENTSRES.fields_by_name['events'].message_type = _EVENT
_LISTEVENTOCCURRENCESRES.fields_by_name['events'].message_type = _EVENT
_TRANSFEREVENTREQ.oneofs_by_name['new_owner'].fields.append(
  _TRANSFEREVENTREQ.fields_by_name['new_owner_community_id'])
_TRANSFEREVENTREQ.fields_by_name['new_owner_community_id'].containing_oneof = _TRANSFEREVENTREQ.oneofs_by_name['new_owner']
_TRANSFEREVENTREQ.oneofs_by_name['new_owner'].fields.append(
  _TRANSFEREVENTREQ.fields_by_name['new_owner_group_id'])
_TRANSFEREVENTREQ.fields_by_name['new_owner_group_id'].containing_oneof = _TRANSFEREVENTREQ.oneofs_by_name['new_owner']
_SETEVENTATTENDANCEREQ.fields_by_name['attendance_state'].enum_type = _ATTENDANCESTATE
DESCRIPTOR.message_types_by_name['OnlineEventInformation'] = _ONLINEEVENTINFORMATION
DESCRIPTOR.message_types_by_name['OfflineEventInformation'] = _OFFLINEEVENTINFORMATION
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
DESCRIPTOR.message_types_by_name['CreateEventReq'] = _CREATEEVENTREQ
DESCRIPTOR.message_types_by_name['ScheduleEventReq'] = _SCHEDULEEVENTREQ
DESCRIPTOR.message_types_by_name['UpdateEventReq'] = _UPDATEEVENTREQ
DESCRIPTOR.message_types_by_name['GetEventReq'] = _GETEVENTREQ
DESCRIPTOR.message_types_by_name['ListEventAttendeesReq'] = _LISTEVENTATTENDEESREQ
DESCRIPTOR.message_types_by_name['ListEventAttendeesRes'] = _LISTEVENTATTENDEESRES
DESCRIPTOR.message_types_by_name['ListEventSubscribersReq'] = _LISTEVENTSUBSCRIBERSREQ
DESCRIPTOR.message_types_by_name['ListEventSubscribersRes'] = _LISTEVENTSUBSCRIBERSRES
DESCRIPTOR.message_types_by_name['ListEventOrganizersReq'] = _LISTEVENTORGANIZERSREQ
DESCRIPTOR.message_types_by_name['ListEventOrganizersRes'] = _LISTEVENTORGANIZERSRES
DESCRIPTOR.message_types_by_name['ListMyEventsReq'] = _LISTMYEVENTSREQ
DESCRIPTOR.message_types_by_name['ListMyEventsRes'] = _LISTMYEVENTSRES
DESCRIPTOR.message_types_by_name['ListAllEventsReq'] = _LISTALLEVENTSREQ
DESCRIPTOR.message_types_by_name['ListAllEventsRes'] = _LISTALLEVENTSRES
DESCRIPTOR.message_types_by_name['ListEventOccurrencesReq'] = _LISTEVENTOCCURRENCESREQ
DESCRIPTOR.message_types_by_name['ListEventOccurrencesRes'] = _LISTEVENTOCCURRENCESRES
DESCRIPTOR.message_types_by_name['TransferEventReq'] = _TRANSFEREVENTREQ
DESCRIPTOR.message_types_by_name['SetEventSubscriptionReq'] = _SETEVENTSUBSCRIPTIONREQ
DESCRIPTOR.message_types_by_name['SetEventAttendanceReq'] = _SETEVENTATTENDANCEREQ
DESCRIPTOR.message_types_by_name['InviteEventOrganizerReq'] = _INVITEEVENTORGANIZERREQ
DESCRIPTOR.message_types_by_name['RemoveEventOrganizerReq'] = _REMOVEEVENTORGANIZERREQ
DESCRIPTOR.enum_types_by_name['AttendanceState'] = _ATTENDANCESTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OnlineEventInformation = _reflection.GeneratedProtocolMessageType('OnlineEventInformation', (_message.Message,), {
  'DESCRIPTOR' : _ONLINEEVENTINFORMATION,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.OnlineEventInformation)
  })
_sym_db.RegisterMessage(OnlineEventInformation)

OfflineEventInformation = _reflection.GeneratedProtocolMessageType('OfflineEventInformation', (_message.Message,), {
  'DESCRIPTOR' : _OFFLINEEVENTINFORMATION,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.OfflineEventInformation)
  })
_sym_db.RegisterMessage(OfflineEventInformation)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.Event)
  })
_sym_db.RegisterMessage(Event)

CreateEventReq = _reflection.GeneratedProtocolMessageType('CreateEventReq', (_message.Message,), {
  'DESCRIPTOR' : _CREATEEVENTREQ,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.CreateEventReq)
  })
_sym_db.RegisterMessage(CreateEventReq)

ScheduleEventReq = _reflection.GeneratedProtocolMessageType('ScheduleEventReq', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEEVENTREQ,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.ScheduleEventReq)
  })
_sym_db.RegisterMessage(ScheduleEventReq)

UpdateEventReq = _reflection.GeneratedProtocolMessageType('UpdateEventReq', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEVENTREQ,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.UpdateEventReq)
  })
_sym_db.RegisterMessage(UpdateEventReq)

GetEventReq = _reflection.GeneratedProtocolMessageType('GetEventReq', (_message.Message,), {
  'DESCRIPTOR' : _GETEVENTREQ,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.GetEventReq)
  })
_sym_db.RegisterMessage(GetEventReq)

ListEventAttendeesReq = _reflection.GeneratedProtocolMessageType('ListEventAttendeesReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTATTENDEESREQ,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.ListEventAttendeesReq)
  })
_sym_db.RegisterMessage(ListEventAttendeesReq)

ListEventAttendeesRes = _reflection.GeneratedProtocolMessageType('ListEventAttendeesRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTATTENDEESRES,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.ListEventAttendeesRes)
  })
_sym_db.RegisterMessage(ListEventAttendeesRes)

ListEventSubscribersReq = _reflection.GeneratedProtocolMessageType('ListEventSubscribersReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTSUBSCRIBERSREQ,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.ListEventSubscribersReq)
  })
_sym_db.RegisterMessage(ListEventSubscribersReq)

ListEventSubscribersRes = _reflection.GeneratedProtocolMessageType('ListEventSubscribersRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTSUBSCRIBERSRES,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.ListEventSubscribersRes)
  })
_sym_db.RegisterMessage(ListEventSubscribersRes)

ListEventOrganizersReq = _reflection.GeneratedProtocolMessageType('ListEventOrganizersReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTORGANIZERSREQ,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.ListEventOrganizersReq)
  })
_sym_db.RegisterMessage(ListEventOrganizersReq)

ListEventOrganizersRes = _reflection.GeneratedProtocolMessageType('ListEventOrganizersRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTORGANIZERSRES,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.ListEventOrganizersRes)
  })
_sym_db.RegisterMessage(ListEventOrganizersRes)

ListMyEventsReq = _reflection.GeneratedProtocolMessageType('ListMyEventsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTMYEVENTSREQ,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.ListMyEventsReq)
  })
_sym_db.RegisterMessage(ListMyEventsReq)

ListMyEventsRes = _reflection.GeneratedProtocolMessageType('ListMyEventsRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTMYEVENTSRES,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.ListMyEventsRes)
  })
_sym_db.RegisterMessage(ListMyEventsRes)

ListAllEventsReq = _reflection.GeneratedProtocolMessageType('ListAllEventsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTALLEVENTSREQ,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.ListAllEventsReq)
  })
_sym_db.RegisterMessage(ListAllEventsReq)

ListAllEventsRes = _reflection.GeneratedProtocolMessageType('ListAllEventsRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTALLEVENTSRES,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.ListAllEventsRes)
  })
_sym_db.RegisterMessage(ListAllEventsRes)

ListEventOccurrencesReq = _reflection.GeneratedProtocolMessageType('ListEventOccurrencesReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTOCCURRENCESREQ,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.ListEventOccurrencesReq)
  })
_sym_db.RegisterMessage(ListEventOccurrencesReq)

ListEventOccurrencesRes = _reflection.GeneratedProtocolMessageType('ListEventOccurrencesRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTOCCURRENCESRES,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.ListEventOccurrencesRes)
  })
_sym_db.RegisterMessage(ListEventOccurrencesRes)

TransferEventReq = _reflection.GeneratedProtocolMessageType('TransferEventReq', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFEREVENTREQ,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.TransferEventReq)
  })
_sym_db.RegisterMessage(TransferEventReq)

SetEventSubscriptionReq = _reflection.GeneratedProtocolMessageType('SetEventSubscriptionReq', (_message.Message,), {
  'DESCRIPTOR' : _SETEVENTSUBSCRIPTIONREQ,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.SetEventSubscriptionReq)
  })
_sym_db.RegisterMessage(SetEventSubscriptionReq)

SetEventAttendanceReq = _reflection.GeneratedProtocolMessageType('SetEventAttendanceReq', (_message.Message,), {
  'DESCRIPTOR' : _SETEVENTATTENDANCEREQ,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.SetEventAttendanceReq)
  })
_sym_db.RegisterMessage(SetEventAttendanceReq)

InviteEventOrganizerReq = _reflection.GeneratedProtocolMessageType('InviteEventOrganizerReq', (_message.Message,), {
  'DESCRIPTOR' : _INVITEEVENTORGANIZERREQ,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.InviteEventOrganizerReq)
  })
_sym_db.RegisterMessage(InviteEventOrganizerReq)

RemoveEventOrganizerReq = _reflection.GeneratedProtocolMessageType('RemoveEventOrganizerReq', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEEVENTORGANIZERREQ,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.events.RemoveEventOrganizerReq)
  })
_sym_db.RegisterMessage(RemoveEventOrganizerReq)



_EVENTS = _descriptor.ServiceDescriptor(
  name='Events',
  full_name='org.couchers.api.events.Events',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\003',
  create_key=_descriptor._internal_create_key,
  serialized_start=4083,
  serialized_end=5663,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateEvent',
    full_name='org.couchers.api.events.Events.CreateEvent',
    index=0,
    containing_service=None,
    input_type=_CREATEEVENTREQ,
    output_type=_EVENT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ScheduleEvent',
    full_name='org.couchers.api.events.Events.ScheduleEvent',
    index=1,
    containing_service=None,
    input_type=_SCHEDULEEVENTREQ,
    output_type=_EVENT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateEvent',
    full_name='org.couchers.api.events.Events.UpdateEvent',
    index=2,
    containing_service=None,
    input_type=_UPDATEEVENTREQ,
    output_type=_EVENT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEvent',
    full_name='org.couchers.api.events.Events.GetEvent',
    index=3,
    containing_service=None,
    input_type=_GETEVENTREQ,
    output_type=_EVENT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListEventOccurrences',
    full_name='org.couchers.api.events.Events.ListEventOccurrences',
    index=4,
    containing_service=None,
    input_type=_LISTEVENTOCCURRENCESREQ,
    output_type=_LISTEVENTOCCURRENCESRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListEventAttendees',
    full_name='org.couchers.api.events.Events.ListEventAttendees',
    index=5,
    containing_service=None,
    input_type=_LISTEVENTATTENDEESREQ,
    output_type=_LISTEVENTATTENDEESRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListEventSubscribers',
    full_name='org.couchers.api.events.Events.ListEventSubscribers',
    index=6,
    containing_service=None,
    input_type=_LISTEVENTSUBSCRIBERSREQ,
    output_type=_LISTEVENTSUBSCRIBERSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListEventOrganizers',
    full_name='org.couchers.api.events.Events.ListEventOrganizers',
    index=7,
    containing_service=None,
    input_type=_LISTEVENTORGANIZERSREQ,
    output_type=_LISTEVENTORGANIZERSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TransferEvent',
    full_name='org.couchers.api.events.Events.TransferEvent',
    index=8,
    containing_service=None,
    input_type=_TRANSFEREVENTREQ,
    output_type=_EVENT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetEventSubscription',
    full_name='org.couchers.api.events.Events.SetEventSubscription',
    index=9,
    containing_service=None,
    input_type=_SETEVENTSUBSCRIPTIONREQ,
    output_type=_EVENT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetEventAttendance',
    full_name='org.couchers.api.events.Events.SetEventAttendance',
    index=10,
    containing_service=None,
    input_type=_SETEVENTATTENDANCEREQ,
    output_type=_EVENT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InviteEventOrganizer',
    full_name='org.couchers.api.events.Events.InviteEventOrganizer',
    index=11,
    containing_service=None,
    input_type=_INVITEEVENTORGANIZERREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveEventOrganizer',
    full_name='org.couchers.api.events.Events.RemoveEventOrganizer',
    index=12,
    containing_service=None,
    input_type=_REMOVEEVENTORGANIZERREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListMyEvents',
    full_name='org.couchers.api.events.Events.ListMyEvents',
    index=13,
    containing_service=None,
    input_type=_LISTMYEVENTSREQ,
    output_type=_LISTMYEVENTSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAllEvents',
    full_name='org.couchers.api.events.Events.ListAllEvents',
    index=14,
    containing_service=None,
    input_type=_LISTALLEVENTSREQ,
    output_type=_LISTALLEVENTSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EVENTS)

DESCRIPTOR.services_by_name['Events'] = _EVENTS

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: reporting.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='reporting.proto',
  package='org.couchers.api.reporting',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0freporting.proto\x12\x1aorg.couchers.api.reporting\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto\"|\n\tReportReq\x12\x0e\n\x06reason\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x13\n\x0b\x63ontent_ref\x18\x03 \x01(\t\x12\x13\n\x0b\x61uthor_user\x18\x04 \x01(\t\x12\x12\n\nuser_agent\x18\x05 \x01(\t\x12\x0c\n\x04page\x18\x06 \x01(\t2\\\n\tReporting\x12I\n\x06Report\x12%.org.couchers.api.reporting.ReportReq\x1a\x16.google.protobuf.Empty\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,])




_REPORTREQ = _descriptor.Descriptor(
  name='ReportReq',
  full_name='org.couchers.api.reporting.ReportReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reason', full_name='org.couchers.api.reporting.ReportReq.reason', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='org.couchers.api.reporting.ReportReq.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_ref', full_name='org.couchers.api.reporting.ReportReq.content_ref', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='author_user', full_name='org.couchers.api.reporting.ReportReq.author_user', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_agent', full_name='org.couchers.api.reporting.ReportReq.user_agent', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page', full_name='org.couchers.api.reporting.ReportReq.page', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=219,
)

DESCRIPTOR.message_types_by_name['ReportReq'] = _REPORTREQ
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ReportReq = _reflection.GeneratedProtocolMessageType('ReportReq', (_message.Message,), {
  'DESCRIPTOR' : _REPORTREQ,
  '__module__' : 'reporting_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.reporting.ReportReq)
  })
_sym_db.RegisterMessage(ReportReq)



_REPORTING = _descriptor.ServiceDescriptor(
  name='Reporting',
  full_name='org.couchers.api.reporting.Reporting',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\003',
  create_key=_descriptor._internal_create_key,
  serialized_start=221,
  serialized_end=313,
  methods=[
  _descriptor.MethodDescriptor(
    name='Report',
    full_name='org.couchers.api.reporting.Reporting.Report',
    index=0,
    containing_service=None,
    input_type=_REPORTREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_REPORTING)

DESCRIPTOR.services_by_name['Reporting'] = _REPORTING

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: annotations.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='annotations.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11\x61nnotations.proto\x1a google/protobuf/descriptor.proto*|\n\tAuthLevel\x12\x16\n\x12\x41UTH_LEVEL_UNKNOWN\x10\x00\x12\x13\n\x0f\x41UTH_LEVEL_OPEN\x10\x01\x12\x15\n\x11\x41UTH_LEVEL_JAILED\x10\x02\x12\x15\n\x11\x41UTH_LEVEL_SECURE\x10\x03\x12\x14\n\x10\x41UTH_LEVEL_ADMIN\x10\x04:2\n\tsensitive\x12\x1d.google.protobuf.FieldOptions\x18\xd0\x86\x03 \x01(\x08:A\n\nauth_level\x12\x1f.google.protobuf.ServiceOptions\x18\xd1\x86\x03 \x01(\x0e\x32\n.AuthLevelb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])

_AUTHLEVEL = _descriptor.EnumDescriptor(
  name='AuthLevel',
  full_name='AuthLevel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTH_LEVEL_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTH_LEVEL_OPEN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTH_LEVEL_JAILED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTH_LEVEL_SECURE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTH_LEVEL_ADMIN', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55,
  serialized_end=179,
)
_sym_db.RegisterEnumDescriptor(_AUTHLEVEL)

AuthLevel = enum_type_wrapper.EnumTypeWrapper(_AUTHLEVEL)
AUTH_LEVEL_UNKNOWN = 0
AUTH_LEVEL_OPEN = 1
AUTH_LEVEL_JAILED = 2
AUTH_LEVEL_SECURE = 3
AUTH_LEVEL_ADMIN = 4

SENSITIVE_FIELD_NUMBER = 50000
sensitive = _descriptor.FieldDescriptor(
  name='sensitive', full_name='sensitive', index=0,
  number=50000, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
AUTH_LEVEL_FIELD_NUMBER = 50001
auth_level = _descriptor.FieldDescriptor(
  name='auth_level', full_name='auth_level', index=1,
  number=50001, type=14, cpp_type=8, label=1,
  has_default_value=False, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)

DESCRIPTOR.enum_types_by_name['AuthLevel'] = _AUTHLEVEL
DESCRIPTOR.extensions_by_name['sensitive'] = sensitive
DESCRIPTOR.extensions_by_name['auth_level'] = auth_level
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(sensitive)
auth_level.enum_type = _AUTHLEVEL
google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(auth_level)

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import jail_pb2 as jail__pb2


class JailStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.JailInfo = channel.unary_unary(
                '/org.couchers.jail.Jail/JailInfo',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=jail__pb2.JailInfoRes.FromString,
                )
        self.AcceptTOS = channel.unary_unary(
                '/org.couchers.jail.Jail/AcceptTOS',
                request_serializer=jail__pb2.AcceptTOSReq.SerializeToString,
                response_deserializer=jail__pb2.JailInfoRes.FromString,
                )
        self.SetLocation = channel.unary_unary(
                '/org.couchers.jail.Jail/SetLocation',
                request_serializer=jail__pb2.SetLocationReq.SerializeToString,
                response_deserializer=jail__pb2.JailInfoRes.FromString,
                )
        self.AcceptCommunityGuidelines = channel.unary_unary(
                '/org.couchers.jail.Jail/AcceptCommunityGuidelines',
                request_serializer=jail__pb2.AcceptCommunityGuidelinesReq.SerializeToString,
                response_deserializer=jail__pb2.JailInfoRes.FromString,
                )


class JailServicer(object):
    """Missing associated documentation comment in .proto file."""

    def JailInfo(self, request, context):
        """
        Jail API

        If the user hasn't completed necessary steps needed to use the app, they are
        only allowed to hit the Jail API.

        E.g. if signing up is incomplete, or they haven't agreed to TOS, etc.

        These API functions are available only to signed-in users, but while other
        APIs can't be used while Jailed, these can.
        Get reason why the user is in jail, e.g. hasn't completed all sign-up
        steps, or needs to read something, etc
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AcceptTOS(self, request, context):
        """Accept TOS
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetLocation(self, request, context):
        """Set the user's location
        If you're not jailed, do this with api.UpdateProfile!
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AcceptCommunityGuidelines(self, request, context):
        """Accept community guidelines
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_JailServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'JailInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.JailInfo,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=jail__pb2.JailInfoRes.SerializeToString,
            ),
            'AcceptTOS': grpc.unary_unary_rpc_method_handler(
                    servicer.AcceptTOS,
                    request_deserializer=jail__pb2.AcceptTOSReq.FromString,
                    response_serializer=jail__pb2.JailInfoRes.SerializeToString,
            ),
            'SetLocation': grpc.unary_unary_rpc_method_handler(
                    servicer.SetLocation,
                    request_deserializer=jail__pb2.SetLocationReq.FromString,
                    response_serializer=jail__pb2.JailInfoRes.SerializeToString,
            ),
            'AcceptCommunityGuidelines': grpc.unary_unary_rpc_method_handler(
                    servicer.AcceptCommunityGuidelines,
                    request_deserializer=jail__pb2.AcceptCommunityGuidelinesReq.FromString,
                    response_serializer=jail__pb2.JailInfoRes.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.jail.Jail', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Jail(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def JailInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.jail.Jail/JailInfo',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            jail__pb2.JailInfoRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AcceptTOS(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.jail.Jail/AcceptTOS',
            jail__pb2.AcceptTOSReq.SerializeToString,
            jail__pb2.JailInfoRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetLocation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.jail.Jail/SetLocation',
            jail__pb2.SetLocationReq.SerializeToString,
            jail__pb2.JailInfoRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AcceptCommunityGuidelines(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.jail.Jail/AcceptCommunityGuidelines',
            jail__pb2.AcceptCommunityGuidelinesReq.SerializeToString,
            jail__pb2.JailInfoRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: jail.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='jail.proto',
  package='org.couchers.jail',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\njail.proto\x12\x11org.couchers.jail\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto\"\x8a\x01\n\x0bJailInfoRes\x12\x0e\n\x06jailed\x18\x01 \x01(\x08\x12\x1c\n\x14has_not_accepted_tos\x18\x02 \x01(\x08\x12\x1e\n\x16has_not_added_location\x18\x03 \x01(\x08\x12-\n%has_not_accepted_community_guidelines\x18\x04 \x01(\x08\"\x1e\n\x0c\x41\x63\x63\x65ptTOSReq\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x01 \x01(\x08\"H\n\x0eSetLocationReq\x12\x0c\n\x04\x63ity\x18\x01 \x01(\t\x12\x0b\n\x03lat\x18\x02 \x01(\x01\x12\x0b\n\x03lng\x18\x03 \x01(\x01\x12\x0e\n\x06radius\x18\x04 \x01(\x01\".\n\x1c\x41\x63\x63\x65ptCommunityGuidelinesReq\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x01 \x01(\x08\x32\xe6\x02\n\x04Jail\x12\x44\n\x08JailInfo\x12\x16.google.protobuf.Empty\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x12N\n\tAcceptTOS\x12\x1f.org.couchers.jail.AcceptTOSReq\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x12R\n\x0bSetLocation\x12!.org.couchers.jail.SetLocationReq\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x12n\n\x19\x41\x63\x63\x65ptCommunityGuidelines\x12/.org.couchers.jail.AcceptCommunityGuidelinesReq\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x1a\x04\x88\xb5\x18\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,])




_JAILINFORES = _descriptor.Descriptor(
  name='JailInfoRes',
  full_name='org.couchers.jail.JailInfoRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jailed', full_name='org.couchers.jail.JailInfoRes.jailed', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_not_accepted_tos', full_name='org.couchers.jail.JailInfoRes.has_not_accepted_tos', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_not_added_location', full_name='org.couchers.jail.JailInfoRes.has_not_added_location', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_not_accepted_community_guidelines', full_name='org.couchers.jail.JailInfoRes.has_not_accepted_community_guidelines', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=220,
)


_ACCEPTTOSREQ = _descriptor.Descriptor(
  name='AcceptTOSReq',
  full_name='org.couchers.jail.AcceptTOSReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accept', full_name='org.couchers.jail.AcceptTOSReq.accept', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=252,
)


_SETLOCATIONREQ = _descriptor.Descriptor(
  name='SetLocationReq',
  full_name='org.couchers.jail.SetLocationReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='city', full_name='org.couchers.jail.SetLocationReq.city', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lat', full_name='org.couchers.jail.SetLocationReq.lat', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lng', full_name='org.couchers.jail.SetLocationReq.lng', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radius', full_name='org.couchers.jail.SetLocationReq.radius', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=254,
  serialized_end=326,
)


_ACCEPTCOMMUNITYGUIDELINESREQ = _descriptor.Descriptor(
  name='AcceptCommunityGuidelinesReq',
  full_name='org.couchers.jail.AcceptCommunityGuidelinesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accept', full_name='org.couchers.jail.AcceptCommunityGuidelinesReq.accept', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=374,
)

DESCRIPTOR.message_types_by_name['JailInfoRes'] = _JAILINFORES
DESCRIPTOR.message_types_by_name['AcceptTOSReq'] = _ACCEPTTOSREQ
DESCRIPTOR.message_types_by_name['SetLocationReq'] = _SETLOCATIONREQ
DESCRIPTOR.message_types_by_name['AcceptCommunityGuidelinesReq'] = _ACCEPTCOMMUNITYGUIDELINESREQ
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

JailInfoRes = _reflection.GeneratedProtocolMessageType('JailInfoRes', (_message.Message,), {
  'DESCRIPTOR' : _JAILINFORES,
  '__module__' : 'jail_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.jail.JailInfoRes)
  })
_sym_db.RegisterMessage(JailInfoRes)

AcceptTOSReq = _reflection.GeneratedProtocolMessageType('AcceptTOSReq', (_message.Message,), {
  'DESCRIPTOR' : _ACCEPTTOSREQ,
  '__module__' : 'jail_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.jail.AcceptTOSReq)
  })
_sym_db.RegisterMessage(AcceptTOSReq)

SetLocationReq = _reflection.GeneratedProtocolMessageType('SetLocationReq', (_message.Message,), {
  'DESCRIPTOR' : _SETLOCATIONREQ,
  '__module__' : 'jail_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.jail.SetLocationReq)
  })
_sym_db.RegisterMessage(SetLocationReq)

AcceptCommunityGuidelinesReq = _reflection.GeneratedProtocolMessageType('AcceptCommunityGuidelinesReq', (_message.Message,), {
  'DESCRIPTOR' : _ACCEPTCOMMUNITYGUIDELINESREQ,
  '__module__' : 'jail_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.jail.AcceptCommunityGuidelinesReq)
  })
_sym_db.RegisterMessage(AcceptCommunityGuidelinesReq)



_JAIL = _descriptor.ServiceDescriptor(
  name='Jail',
  full_name='org.couchers.jail.Jail',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\002',
  create_key=_descriptor._internal_create_key,
  serialized_start=377,
  serialized_end=735,
  methods=[
  _descriptor.MethodDescriptor(
    name='JailInfo',
    full_name='org.couchers.jail.Jail.JailInfo',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_JAILINFORES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AcceptTOS',
    full_name='org.couchers.jail.Jail.AcceptTOS',
    index=1,
    containing_service=None,
    input_type=_ACCEPTTOSREQ,
    output_type=_JAILINFORES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetLocation',
    full_name='org.couchers.jail.Jail.SetLocation',
    index=2,
    containing_service=None,
    input_type=_SETLOCATIONREQ,
    output_type=_JAILINFORES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AcceptCommunityGuidelines',
    full_name='org.couchers.jail.Jail.AcceptCommunityGuidelines',
    index=3,
    containing_service=None,
    input_type=_ACCEPTCOMMUNITYGUIDELINESREQ,
    output_type=_JAILINFORES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_JAIL)

DESCRIPTOR.services_by_name['Jail'] = _JAIL

# @@protoc_insertion_point(module_scope)
